﻿using NPOI.SS.UserModel;
using Performance.DtoModels;
using Performance.Infrastructure;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Performance.Services
{
    public class PerSheetService : IAutoInjection
    {
        public PerSheet Sheet(ISheet sheet)
        {
            PerSheet perSheet = new PerSheet();
            perSheet.SheetName = sheet.SheetName;
            perSheet.SheetType = GetSheetType(sheet.SheetName);
            perSheet.ModuleName = EnumHelper.GetDescription(perSheet.SheetType);

            if (perSheet.SheetType == SheetType.Unidentifiable)
                return null;

            var sheetRead = PerSheetDataFactory.GetDataRead(perSheet.SheetType);
            perSheet.PerData = AnalyzeData(sheet, sheetRead);

            return perSheet;
        }

        public SheetType GetSheetType(string sheetName)
        {
            if (sheetName.StartsWith("医院人员名单"))
                return SheetType.Employee;
            else if (sheetName.StartsWith("1."))
                return SheetType.Income;
            else if (sheetName.StartsWith("2."))
                return SheetType.Expend;
            else if (sheetName.StartsWith("3."))
                return SheetType.Workload;
            return SheetType.Unidentifiable;
        }

        public List<PerData> AnalyzeData(ISheet sheet, IPerSheetDataRead sheetRead)
        {
            List<PerData> dataList = new List<PerData>();
            PerHeaderService perHeader = new PerHeaderService();
            var headList = perHeader.GetPerHeaderReverse(sheet, sheetRead.Point);
            var vhead = headList.Where(t => t.PointCell != sheetRead.Point.AccountingUnitCellNum && t.PointCell != sheetRead.Point.DeptCellNum)
                .OrderBy(t => t.PointCell);

            for (int r = sheetRead.Point.DataFirstRowNum.Value; r < sheet.LastRowNum + 1; r++)
            {
                var row = sheet.GetRow(r);
                for (int c = 0; c < vhead.Count(); c++)
                {
                    PerData data = sheetRead.GetPerData(row, vhead.ElementAt(c));
                    dataList.Add(data);
                }
            }
            return dataList;
        }
    }
}
